@@ -41,33 +41,27 @@
 
 class Golf : public DealerScene
 {
-    friend class GolfSolver;
-
     Q_OBJECT
 
 public:
-    Golf( );
-    void deal();
-    virtual void restart();
-
-public slots:
-    virtual Card *newCards();
+    virtual void initialize();
 
 protected:
-    virtual bool drop() { return false; }
-    virtual bool cardClicked(Card *c);
     virtual void setGameState( const QString & );
+    virtual bool checkAdd(const PatPile * pile, const QList<KCard*> & oldCards, const QList<KCard*> & newCards) const;
+    virtual bool checkRemove(const PatPile * pile, const QList<KCard*> & cards) const;
+    virtual void restart();
+    virtual bool drop();
 
-private: // functions
-    virtual bool checkAdd( int checkIndex, const Pile *c1, const CardList& c2) const;
-    virtual bool checkRemove( int checkIndex, const Pile *c1, const Card *c2) const;
+protected slots:
+    virtual bool newCards();
 
 private:
-    Pile* talon;
-    Pile* stack[7];
-    Pile* waste;
+    PatPile* talon;
+    PatPile* stack[7];
+    PatPile* waste;
+
+    friend class GolfSolver;
 };
 
 #endif
-
-//-------------------------------------------------------------------------//
