@@ -1,6 +1,7 @@
 /*
  * Copyright (C) 1995 Paul Olav Tvete <paul@troll.no>
  * Copyright (C) 2000-2009 Stephan Kulow <coolo@kde.org>
+ * Copyright (C) 2010 Parker Coates <parker.coates@kdemail.net>
  *
  * License of original code:
  * -------------------------------------------------------------------------
@@ -36,74 +37,84 @@
 
 #include "grandf.h"
 
-#include "carddeck.h"
 #include "dealerinfo.h"
+#include "pileutils.h"
 #include "speeds.h"
 #include "patsolve/grandfsolver.h"
 
-#include <KDebug>
+#include "Shuffle"
+
 #include <KLocale>
 
 
-Grandf::Grandf( )
-    : DealerScene(  )
+void Grandf::initialize()
 {
-    setDeck(new CardDeck());
+    static_cast<KStandardCardDeck*>( deck() )->setDeckContents();
 
     const qreal distx = 1.4;
     const qreal targetOffset = 1.5 * distx;
 
-    for (int i=0; i<4; i++) {
-        target[i] = new Pile(i+1, QString("target%1").arg(i));
-        target[i]->setPilePos(targetOffset+i*distx, 0);
-        target[i]->setType(Pile::KlondikeTarget);
-        addPile(target[i]);
+    for ( int i = 0; i < 4; ++i )
+    {
+        target[i] = new PatPile( this, i + 1, QString("target%1").arg(i) );
+        target[i]->setPileRole(PatPile::Foundation);
+        target[i]->setLayoutPos(targetOffset+i*distx, 0);
+        target[i]->setSpread(0, 0);
+        target[i]->setKeyboardSelectHint( KCardPile::NeverFocus );
+        target[i]->setKeyboardDropHint( KCardPile::ForceFocusTop );
     }
 
-    for (int i=0; i<7; i++) {
-        store[i] = new Pile(5+i, QString("store%1").arg(i));
-        store[i]->setPilePos(distx*i, 1.2);
-        store[i]->setAddFlags(Pile::addSpread | Pile::several);
-        store[i]->setRemoveFlags(Pile::several | Pile::autoTurnTop);
-        store[i]->setCheckIndex(1);
-        store[i]->setReservedSpace( QSizeF( 1.0, 5.0 ) );
-        addPile(store[i]);
+    for ( int i = 0; i < 7; ++i )
+    {
+        store[i] = new PatPile( this, 5 + i, QString("store%1").arg(i) );
+        store[i]->setPileRole(PatPile::Tableau);
+        store[i]->setLayoutPos(distx*i, 1.2);
+        store[i]->setAutoTurnTop(true);
+        store[i]->setReservedSpace( 0, 0, 1, 5 );
+        store[i]->setKeyboardSelectHint( KCardPile::FreeFocus );
+        store[i]->setKeyboardDropHint( KCardPile::AutoFocusTop );
     }
 
     setActions(DealerScene::Hint | DealerScene::Demo | DealerScene::Redeal);
     setSolver( new GrandfSolver( this ) );
 }
 
-void Grandf::restart() {
-    deck()->returnAllCards();
-    deck()->shuffle( gameNumber() );
-    deal();
+void Grandf::restart()
+{
+    deal( shuffled( deck()->cards(), gameNumber() ) );
     numberOfDeals = 1;
     emit newCardsPossible( true );
 }
 
-Card *Grandf::newCards()
+bool Grandf::newCards()
 {
-    if (numberOfDeals >= 3)
-        return 0;
+    if ( numberOfDeals >= 3 )
+        return false;
 
-    if (deck()->hasAnimatedCards())
-        for (int i = 0; i < 7; ++i)
-            if (store[i]->top())
-                return store[i]->top();
+    // NOTE: This is not quite correct. The piles should be turned face down
+    //       (i.e. partially reversed) during collection.
+    QList<KCard*> collectedCards;
+    for ( int pos = 6; pos >= 0; --pos )
+    {
+        collectedCards << store[pos]->cards();
+        store[pos]->clear();
+    }
+    deal( collectedCards );
 
-    collect();
-    deal();
     numberOfDeals++;
 
-    onGameStateAlteredByUser();
     if (numberOfDeals == 3)
         emit newCardsPossible(false);
 
-    return store[0]->top();
+    return true;
 }
 
-void Grandf::deal() {
+void Grandf::deal( const QList<KCard*> & cardsToDeal )
+{
+    setKeyboardModeActive( false );
+
+    QList<KCard*> cards = cardsToDeal;
+
     QPointF initPos( 1.4 * 3 * deck()->cardWidth(), 1.2 * deck()->cardHeight() );
 
     int start = 0;
@@ -115,9 +126,8 @@ void Grandf::deal() {
         int i = start;
         do
         {
-            Card *next = deck()->takeCard();
-            if (next)
-                addCardForDeal( store[i], next, (i == start), initPos );
+            if (!cards.isEmpty())
+                addCardForDeal( store[i], cards.takeLast(), (i == start), initPos );
             i += dir;
         } while ( i != stop + dir);
         int t = start;
@@ -127,49 +137,41 @@ void Grandf::deal() {
     }
 
     int i = 0;
-    Card *next = deck()->takeCard();
-    while (next)
+    while (!cards.isEmpty())
     {
-        addCardForDeal( store[i+1], next, true, initPos );
-        next = deck()->takeCard();
+        addCardForDeal( store[i+1], cards.takeLast(), true, initPos );
         i = (i+1)%6;
     }
 
     for (int round=0; round < 7; round++)
     {
-        Card *c = store[round]->top();
+        KCard *c = store[round]->top();
         if (c)
-            c->turn(true);
+            c->setFaceUp(true);
     }
 
     startDealAnimation();
 }
 
-/*****************************
-
-  Does the collecting step of the game
-
-  NOTE: this is not quite correct -- the piles should be turned
-  facedown (ie partially reversed) during collection.
-
-******************************/
-void Grandf::collect() {
-    clearHighlightedItems();
-
-    for (int pos = 6; pos >= 0; pos--) {
-        foreach (Card *c, store[pos]->cards())
-            deck()->returnCard(c);
+bool Grandf::checkAdd(const PatPile * pile, const QList<KCard*> & oldCards, const QList<KCard*> & newCards) const
+{
+    switch (pile->pileRole())
+    {
+    case PatPile::Tableau:
+        if (oldCards.isEmpty())
+            return getRank( newCards.first() ) == KStandardCardDeck::King;
+        else
+            return getRank( newCards.first() ) == getRank( oldCards.last() ) - 1
+                   && getSuit( newCards.first() ) == getSuit( oldCards.last() );
+    case PatPile::Foundation:
+    default:
+        return checkAddSameSuitAscendingFromAce(oldCards, newCards);
     }
 }
 
-bool Grandf::checkAdd( int checkIndex, const Pile *c1, const CardList& c2) const {
-    kDebug() << checkIndex << c1->isEmpty();
-    Q_ASSERT (checkIndex == 1);
-    if (c1->isEmpty())
-        return c2.first()->rank() == Card::King;
-    else
-        return (c2.first()->rank() == c1->top()->rank() - 1)
-               && c2.first()->suit() == c1->top()->suit();
+bool Grandf::checkRemove(const PatPile * pile, const QList<KCard*> & cards) const
+{
+    return pile->pileRole() == PatPile::Tableau && cards.first()->isFaceUp();
 }
 
 QString Grandf::getGameState()
