@@ -65,6 +65,7 @@
 #include "settings.h"
 #include "config.h"
 
+using namespace ksudoku;
 
 void KSudoku::onCompleted(bool isCorrect, const QTime& required, bool withHelp) {
 	if(!isCorrect) {
@@ -225,6 +226,7 @@ void KSudoku::startGame(const Game& game) {
 
 	wrapper->layout()->addWidget(widget);
 	widget->show();
+	widget->setFocus();
 
 	connect(game.interface(), SIGNAL(completed(bool,const QTime&,bool)), SLOT(onCompleted(bool,const QTime&,bool)));
 	connect(game.interface(), SIGNAL(modified(bool)), SLOT(onModified(bool)));
@@ -298,9 +300,8 @@ void KSudoku::dubPuzzle()
 		return;
 	}
 
-	int forks = 0;
 	ksudoku::Puzzle* puzzle = game.puzzle()->dubPuzzle();
-	int state = puzzle->init(game.allValues(), &forks);
+	int state = puzzle->init(game.allValues());
 
 	if(state <= 0) {
 		KMessageBox::information(this, i18n("Sorry, no solutions have been found."));
@@ -477,13 +478,15 @@ void KSudoku::gameNew()
 
 	if(!currentView()) return;
 
-	// TODO onyl show this when there is a game running
-	if(KMessageBox::questionYesNo(this, 
+	// only show question when the current game hasn't been finished until now
+	if(!m_gameUI->game().wasFinished()) {
+		if(KMessageBox::questionYesNo(this,
 	                              i18n("Do you really want to end this game in order to start a new one?"),
 	                              i18nc("window title", "Restart Game"),
 	                              KGuiItem(i18nc("button label", "Restart Game")),
 	                              KStandardGuiItem::cancel() ) != KMessageBox::Yes)
-		return;
+			return;
+	}
 
 	showWelcomeScreen();
 }
