@@ -22,8 +22,8 @@
 #include <KLocale>
 #include <KStandardDirs>
 #include <KConfigSkeleton>
-#include <knewstuff2/engine.h>
 #include <KComponentData>
+#include <KNS3/DownloadDialog>
 
 #include "ui_kgamethemeselector.h"
 #include "kgametheme.h"
@@ -180,7 +180,8 @@ void KGameThemeSelector::KGameThemeSelectorPrivate::_k_updatePreview()
 void KGameThemeSelector::KGameThemeSelectorPrivate::_k_updateThemeList(const QString& strTheme)
 {
     //find theme and set selection to the current theme; happens when pressing "Default"
-    if(themeMap.value(ui.themeList->currentItem()->text())->fileName() != strTheme)
+    QListWidgetItem * currentItem = ui.themeList->currentItem();
+    if(!currentItem || themeMap.value(currentItem->text())->fileName() != strTheme)
     {
         for(int i = 0; i < ui.themeList->count(); i++)
         {
@@ -195,12 +196,10 @@ void KGameThemeSelector::KGameThemeSelectorPrivate::_k_updateThemeList(const QSt
 
 void KGameThemeSelector::KGameThemeSelectorPrivate::_k_openKNewStuffDialog()
 {
-    KNS::Entry::List entries = KNS::Engine::download();
-    //rescan themes directory
-    QString currentthemepath = ui.kcfg_Theme->text();
-    if (entries.size()>0) findThemes(currentthemepath);
-    //Needed as the static KNS constructor made copies
-    qDeleteAll(entries);
+    KNS3::DownloadDialog dialog( q );
+    dialog.exec();
+    if ( !dialog.changedEntries().isEmpty() )
+        findThemes( ui.kcfg_Theme->text() );
 }
 
 #include "kgamethemeselector.moc"
